#!/usr/bin/env bash

set -e
pushd libs/python/example/tutorial
  export CONDA_BUILD_SYSROOT=/opt/MacOSX10.10.sdk
  export CONDA_BUILD=1
  bjam -q -d+2 --debug-configuration
  python -c 'from __future__ import print_function; import hello_ext; print(hello_ext.greet())'
popd


set -ex



test -f $PREFIX/include/boost/python.hpp
test -d $PREFIX/include/boost/python
test -f $PREFIX/share/boost-build/src/kernel/site-config.jam
test -f $PREFIX/lib/libboost_python.a
test -f $PREFIX/lib/libboost_python38.a
test -f $PREFIX/lib/libboost_python${SHLIB_EXT}
test -f $PREFIX/lib/libboost_python38${SHLIB_EXT}
test -f $PREFIX/lib/libboost_numpy.a
test -f $PREFIX/lib/libboost_numpy38.a
test -f $PREFIX/lib/libboost_numpy${SHLIB_EXT}
test -f $PREFIX/lib/libboost_numpy38${SHLIB_EXT}
exit 0
